=======
Credits
=======

Development Lead
----------------

* Felix Albrecht <f.albrecht@uni-bonn.com> (enduser commands/statics,
  documentation, director)
* Tobias Raabe <tobiasraabe@uni-bonn.de> (ovmm core)

Contributors
------------

None yet. Why not be the first?
